==> intel-media-driver_24.1.0+dfsg1.orig.tar.xz: media-driver-intel-media-24.1.0/media_softlet/agnostic/common/hw/vdbox/media_srcs.cmake <==
# Copyright (c) 2020-2021, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_cmdpar.h
)

set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_cmdpar.h
)

set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_itf.h
)

set(SOFTLET_MHW_VDBOX_COMMON_HEADERS_
    ${SOFTLET_MHW_VDBOX_COMMON_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_HCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${SOFTLET_MHW_VDBOX_HUC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${SOFTLET_MHW_VDBOX_AVP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${SOFTLET_MHW_VDBOX_MFX_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_}
)

source_group( "MHW\\Vdbox" FILES ${TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_} )

set(TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_ "")

set(SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)

==> intel-media-driver_25.4.2+dfsg1.orig.tar.xz: media-driver-intel-media-25.4.2/media_softlet/agnostic/common/hw/vdbox/media_srcs.cmake <==
# Copyright (c) 2020-2024, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_cmdpar.h
)

set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_itf.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_cmdpar.h
)

set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vvcp_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vvcp_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vvcp_itf.h
)

set(TMP_SOFTLET_MHW_VDBOX_AQM_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_aqm_cmdpar.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_aqm_impl.h
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_aqm_itf.h
)

set(SOFTLET_MHW_VDBOX_COMMON_HEADERS_
    ${SOFTLET_MHW_VDBOX_COMMON_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_HCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${SOFTLET_MHW_VDBOX_HUC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${SOFTLET_MHW_VDBOX_AVP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${SOFTLET_MHW_VDBOX_MFX_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VVCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_AQM_HEADERS_
    ${SOFTLET_MHW_VDBOX_AQM_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AQM_HEADERS_}
)

source_group( "MHW\\Vdbox" FILES ${TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_} ${TMP_SOFTLET_MHW_VDBOX_AQM_HEADERS_})

set(TMP_SOFTLET_MHW_VDBOX_COMMON_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_AQM_HEADERS_ "")

set(SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
